@@ -48,18 +48,20 @@ def execute_raw(sql, database='default'):
         return 1
 
 
-def drop_index(index):
+def drop_index(index, database='default'):
     """
     Check if index exists and drop it
 
     index (dict) : index description
     """
-    if index_exists(index):
+    if 'database' in index:
+        database = index['database']
+
+    if index_exists(index, database):
         logging.info("Will drop %s" % index['name'])
-        if 'database' in index:
-            res = execute_raw(index['cmd'], index['database'])
-        else:
-            res = execute_raw(index['cmd'])
+
+        res = execute_raw(index['cmd'], database)
+
         logging.info("%s dropped" % index['name'])
     else:
         res = 1
@@ -67,7 +69,7 @@ def drop_index(index):
     return res
 
 
-def create_index(index):
+def create_index(index, database='default'):
     """
     Create an index
 
@@ -77,13 +79,14 @@ def create_index(index):
         "cmd": "CREATE INDEX foo_idx ON table (column)"
        }
     """
-    if index_exists(index):
+    if 'database' in index:
+        database = index['database']
+
+    if index_exists(index, database):
         logging.info("%s still exists" % index['name'])
+        res = 1
     else:
         logging.info("Will create %s" % index['name'])
-        if 'database' in index:
-            res = execute_raw(index['cmd'], index['database'])
-        else:
-            res = execute_raw(index['cmd'])
+        res = execute_raw(index['cmd'], database)
         logging.info("%s created" % index['name'])
     return res
